@@ -79,6 +79,7 @@ pub struct Variable {
     pub name: String,
     pub references: Vec<Id<Reference>>,
     pub shadowed: Option<Id<Variable>>,
+    pub is_self: bool,
 }
 
 #[derive(Default)]
@@ -97,7 +98,7 @@ pub enum VariableInScope {
     Blocked,
 }
 
-fn create_scope<'a, N: Node<'a>>(node: N) -> Option<Scope> {
+fn create_scope<N: Node>(node: N) -> Option<Scope> {
     if let Some((start, end)) = node.range() {
         Some(Scope {
             block: (start.bytes(), end.bytes()),
@@ -110,7 +111,7 @@ fn create_scope<'a, N: Node<'a>>(node: N) -> Option<Scope> {
     }
 }
 
-fn range<'a, N: Node<'a>>(node: N) -> (usize, usize) {
+fn range<N: Node>(node: N) -> (usize, usize) {
     let (start, end) = node.range().unwrap();
     (start.bytes(), end.bytes())
 }
@@ -312,18 +313,19 @@ impl ScopeVisitor {
         self.define_name_full(&token.token().to_string(), range(token), definition_range);
     }
 
-    fn define_name_full(
+    fn define_name_full_with_variable(
         &mut self,
         name: &str,
         range: Range,
         definition_range: Range,
+        variable: Variable,
     ) -> Id<Variable> {
         let shadowed = self.find_variable(name).map(|(var, _)| var);
 
         let id = self.scope_manager.variables.alloc(Variable {
             name: name.to_owned(),
             shadowed,
-            ..Variable::default()
+            ..variable
         });
 
         self.current_scope().variables.push(id);
@@ -336,6 +338,15 @@ impl ScopeVisitor {
         id
     }
 
+    fn define_name_full(
+        &mut self,
+        name: &str,
+        range: Range,
+        definition_range: Range,
+    ) -> Id<Variable> {
+        self.define_name_full_with_variable(name, range, definition_range, Variable::default())
+    }
+
     fn try_hoist(&mut self) {
         let latest_reference_id = *self.current_scope().references.last().unwrap();
         let (name, identifier, write_expr) = {
@@ -384,7 +395,7 @@ impl ScopeVisitor {
         self.current_scope().references.push(reference_id);
     }
 
-    fn open_scope<'a, N: Node<'a>>(&mut self, node: N) {
+    fn open_scope<N: Node>(&mut self, node: N) {
         let scope = create_scope(node).unwrap_or_else(Default::default);
         let scope_id = self.scope_manager.scopes.alloc(scope);
         self.scope_stack.push(scope_id);
@@ -399,7 +410,7 @@ impl ScopeVisitor {
     }
 }
 
-impl Visitor<'_> for ScopeVisitor {
+impl Visitor for ScopeVisitor {
     fn visit_assignment(&mut self, assignment: &ast::Assignment) {
         let mut expressions = assignment.expressions().iter();
 
@@ -570,7 +581,15 @@ impl Visitor<'_> for ScopeVisitor {
 
         if let Some(name) = name.method_name() {
             self.open_scope(declaration.body());
-            self.define_name_full("self", range(name), range(name));
+            self.define_name_full_with_variable(
+                "self",
+                range(name),
+                range(name),
+                Variable {
+                    is_self: true,
+                    ..Variable::default()
+                },
+            );
         }
     }
 
